﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using IgaworksUnityAOS;
using Toast.Analytics;

public class AnalyticsManager : MonoBehaviour
{
    private static AnalyticsManager _instance;
    public static AnalyticsManager Instance
    {
        get
        {
            if (_instance == null)
            {
                _instance = GameObject.FindObjectOfType<AnalyticsManager>();
                DontDestroyOnLoad(Instance.gameObject);
                _instance.Init();
                _instance.SetUserInfo();
            }

            return _instance;
        }
    }

    bool EndInit;

    public delegate void DeepLinkResult(string strResult);

    public DeepLinkResult OnDeepLinkResul = null;
    
    // 하단부터는 아날리틱스들의 변수들
    private GoogleAnalyticsV4 GoogleAnalytics;

    void Awake()
    {
        //유니티 엔진이 초기화될 때, IGAW 플러그인을 초기화 합니다.
        IgaworksUnityPluginAOS.InitPlugin();

        //네이티브 SDK를 초기화 합니다.
        IgaworksUnityPluginAOS.Common.startApplication();
        IgaworksUnityPluginAOS.LiveOps.initialize();
        IgaworksUnityPluginAOS.LiveOps.setLiveOpsPopupEventListener();
        IgaworksUnityPluginAOS.OnLiveOpsPopupClick = mOnLiveOpsPopupClick;
        IgaworksUnityPluginAOS.OnLiveOpsCancelPopupBtnClick= mOnLiveOpsCancelPopupBtnClick;
    }

    void mOnLiveOpsPopupClick()
    {
        CloseAllPopup();
        StartCoroutine(processDeeplink());
    }

    void mOnLiveOpsCancelPopupBtnClick()
    {
        ClosePopup();
    }

    IEnumerator processDeeplink()
    {
        while(true)
        {
            yield return null;
            string result = GetDeepLinkURL();
            if(result != "null")
            {
                // 여기에서 처리해주세요
                Debug.Log(result);

                if (OnDeepLinkResul != null)
                {
                    OnDeepLinkResul(result);
                }

                break;
            }
        }
    }

    void Init()
    {
        // 구글 아날리틱스 초기화
        GoogleAnalyticsV4.instance.StartSession();

        // 토스트 아날리틱스 초기화
        int result = GameAnalytics.initializeSdk("yX50lA6wF5rsTqVo", "f9yD4ZWIT64Dam9B", Application.version, true);
        if (result != 0)
        {
            // 토스트 에러..
            Debug.Log("Error GameAnalytics.initializeSdk");
        }

    }

    void SetUserInfo()
    {
        // 토스트 아날리틱스에 유저 아이디 셋팅
        GameAnalytics.setUserId(SystemInfo.deviceUniqueIdentifier, true);
        // 아이디를 셋팅후 추적을 시작하자
        GameAnalytics.traceActivation();
        //GameAnalytics.setDebugMode(true);
        // 애드브릭스 아날리틱스 유저 아이디 설정
        IgaworksUnityPluginAOS.Common.setUserId(SystemInfo.deviceUniqueIdentifier);
        //  팝업을 위한 리소스 불러오기
        IgaworksUnityPluginAOS.LiveOps.requestPopupResource();

        IgaworksUnityPluginAOS.LiveOps.enableService(true);

        IgaworksUnityPluginAOS.LiveOps.setNotificationIconStyle("ic_stat_white_icon", "ic_launcher", "ff9d261c");

        // 쿠폰사용성공 델리게이트 등록							
        IgaworksUnityPluginAOS.OnSendCouponSucceed = OnSendCouponSucceed;
        //쿠폰사용실패 델리게이트 등록							
        IgaworksUnityPluginAOS.OnSendCouponFailed = OnSendCouponFailed;

        EndInit = true;
    }

    public string GetDeepLinkURL()
    {
        return AndroidDeepLink.GetURL();
    }

    public void ResetDeepLinkURL()
    {
        AndroidDeepLink.ResetURL();
    }

    public void SetNormalClientPushEvent(long second, string contentText, int eventID)
    {
        IgaworksUnityPluginAOS.LiveOps.setNormalClientPushEvent(second, contentText, eventID, false);
    }

    public void CancelNormalClientPushEvent(int eventID)
    {
        IgaworksUnityPluginAOS.LiveOps.cancelClientPushEvent(eventID);
    }

    // 로비 광고 불러오기
    public void OpenLobbyPopupWindow()
    {
        IgaworksUnityPluginAOS.LiveOps.showPopUp("FirstScreen");
        // 토스트 팝업 사용 X
        // 그룹 지정이 안됨.
        //GameAnalytics.showCampaign("FirstScreen");
    }

    // 샵 광고 불러오기
    public void OpenShopPopupWindow()
    {
        IgaworksUnityPluginAOS.LiveOps.showPopUp("ShopScreen");
        // 토스트 팝업 사용 X
        // 그룹지정이 안됨
        //GameAnalytics.showCampaign("ShopScreen");
    }

    public void OpenResearchPopupWindow()
    {
        IgaworksUnityPluginAOS.LiveOps.showPopUp("research");
        // 토스트 팝업 사용 X
        // 그룹지정이 안됨
        //GameAnalytics.showCampaign("ShopScreen");
    }


    public void ClosePopup()
    {
        IgaworksUnityPluginAOS.LiveOps.destroyPopup();
    }

    public void CloseAllPopup()
    {
        IgaworksUnityPluginAOS.LiveOps.destroyAllPopups();
    }

    // 종료시 처리
    public void OnDestroy()
    {
        GoogleAnalyticsV4.instance.StopSession();
        IgaworksUnityPluginAOS.Common.endSession();
        GameAnalytics.traceDeactivation();
        IgaworksUnityPluginAOS.LiveOps.pause();
    }

    // 앱 복귀 및 일시 정지시 처리
    public void OnApplicationPause(bool pause)
    {
        if(EndInit == false)
        {
            return;
        }
        if(pause == true)
        {
            GoogleAnalyticsV4.instance.StopSession();
            IgaworksUnityPluginAOS.Common.endSession();
            GameAnalytics.traceDeactivation();
        } else
        {
            GoogleAnalyticsV4.instance.StartSession();
            IgaworksUnityPluginAOS.Common.startSession();
            GameAnalytics.traceActivation();
            IgaworksUnityPluginAOS.LiveOps.resume();            
        }
    }

    // 거래를 위한 로그
    // 게임내 유료 결제를 할때마다 호출해주도록 한다.
    // price는 원화 기준으로 넣어주도록 하자
    // purchase_id 는 결제이후 영수증 번호이다.
    public void LogTransaction(string product_id, string item_name, string purchase_id, double price, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GoogleAnalyticsV4.instance.LogTransaction(product_id, "NOX Games INC.", price, 0.0f, 0.0f, "KRW");
        GoogleAnalyticsV4.instance.LogItem(product_id, item_name, purchase_id, "InappItem", price, 1, "KRW");
        IgaworksUnityPluginAOS.Adbrix.buy(product_id);
        IgaworksUnityPluginAOS.Adbrix.purchase(purchase_id, product_id, item_name, price, 1, IgaworksUnityPluginAOS.Adbrix.Currency.KR_KRW, item_name);
        GameAnalytics.tracePurchase(product_id, (float)price, (float)price, "KRW", sumlevel);
        IgaworksUnityPluginAOS.Adbrix.setCustomCohort(IgaworksUnityPluginAOS.CohortVariable.COHORT_2, product_id);
    }

    // 입수 로그
    // 인앱 결제로 젬 구매
    public void LogIAPGetGem(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("IAP", "0", gem_value, sumlevel);
    }

    // 일일 업적으로 젬 습득
    public void LogDayGetGem(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("ACHIEVEMENT_DAY", "0", gem_value, sumlevel);
    }

    // 주간 업적으로 젬을 습득
    public void LogWeekGetGem(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("ACHIEVEMENT_WEEK", "0", gem_value, sumlevel);
    }

    // 레벨 업적으로 젬을 습득
    public void LogLevelGetGem(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("ACHIEVEMENT_LEVEL", "0", gem_value, sumlevel);
    }

    // 수호자 레벨업적으로 젬을 습득
    public void LogGuardianLevelGetGem(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("GUARDIAN_LEVEL", "0", gem_value, sumlevel);
    }

    // 조력자 업적으로 젬을 습득
    public void LogHelperGetGem(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("HELPER", "0", gem_value, sumlevel);
    }

    // 균열던전 업적으로 젬을 습득
    public void LogCrackDungeonGetGem(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("CRACK_DUNGEON", "0", gem_value, sumlevel);
    }

    // 투기장 결투랭킹으로 젬을 습득
    public void LogColosseumGetGem(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("COLOSSEUM", "0", gem_value, sumlevel);
    }

    // 수호자 달성 업적 으로 골드 획득
    public void LogGuardstoneGetGold(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("GUARDSTONE", "1", gold_value, sumlevel);
    }

    // 룬스톤 획득 업적 으로 골드 획득
    public void LogRunestoneGetGold(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("RUNESTONE", "1", gold_value, sumlevel);
    }

    // 아이템 강화 업적 으로 골드 획득
    public void LogItemUpgradeGetGold(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("ITEM_UPGRADE", "1", gold_value, sumlevel);
    }

    // 시나리오 진행으로 골드 획득
    public void LogReadScenarioGetGold(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("READ_SCENARIO", "1", gold_value, sumlevel);
    }

    // 아이템을 판매하여 골드 획득
    public void LogSellItemGetGold(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("ITEM_SELL", "1", gold_value, sumlevel);
    }

    // 던전 클리어로 골드 획득
    public void LogDungeonGetGold(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("DUNGEON", "1", gold_value, sumlevel);
    }

    // 던전 반복클리어로 골드 획득
    public void LogRepetDungeonGetGold(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("DUNGEON_REPET", "1", gold_value, sumlevel);
    }

    // 초월던전 클리어로 골드 획득
    public void LogTrancendenceDungeonGetGold(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("TRANSCENDENCE", "1", gold_value, sumlevel);
    }

    // 균열던전 클리어로 골드획득
    public void LogCrackDungeonGetGold(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyAcquisition("CRACK", "1", gold_value, sumlevel);
    }

    // 젬 소모
    // 젬을 골드로 바꾼다.
    public void LogGemToGold(int gem_value, int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("GOLD", "0", gem_value, sumlevel);
        GameAnalytics.traceMoneyAcquisition("GEM", "1", gold_value, sumlevel);
    }

    // 젬을 아이템으로 바꾸었다.
    public void LogGemToItem(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("ITEM", "0", gem_value, sumlevel);
    }

    // 젬을 룬스톤으로 바꾸었다.
    public void LogGemToRune(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("RUNE", "0", gem_value, sumlevel);
    }

    // 젬을 아이템 옵션변경에 사용했다.
    public void LogGemToItemOption(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("ITEM_OPTION", "0", gem_value, sumlevel);
    }

    // 젬을 열쇠로 바꾸었다.
    public void LogGemToKey(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("KEY", "0", gem_value, sumlevel);
    }

    // 젬으로 조력자를 구매하였다.
    public void LogGemToHelper(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("HELPER", "0", gem_value, sumlevel);
    }

    // 젬으로 스킬포인트를 구매하였다.
    public void LogGemToSkillPoint(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("SKILLPOINT", "0", gem_value, sumlevel);
    }

    // 젬으로 아바타장비를 구매하였다.
    public void LogGemToAvatar(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("AVATAR", "0", gem_value, sumlevel);
    }

    // 젬으로 균열석을 구매하였다.
    public void LogGemToCrack(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("CRACK", "0", gem_value, sumlevel);
    }

    // 젬으로 가방을 확장하였다.
    public void LogGemToBag(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("BAG", "0", gem_value, sumlevel);
    }

    // 젬으로 투기장 초기화
    public void LogGemToResetColosseum(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("RESET_COLOSSEUM", "0", gem_value, sumlevel);
    }

    // 젬으로 균열 초기화
    public void LogGemToResetCrack(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("RESET_CRACK", "0", gem_value, sumlevel);
    }

    // 젬으로 일일던전 초기화
    public void LogGemToResetDay(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("RESET_DAY", "0", gem_value, sumlevel);
    }

    // 젬으로 정예던전 초기화
    public void LogGemToResetHardDungeon(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("RESET_HARD", "0", gem_value, sumlevel);
    }

    // 젬으로 길드마크 초기화
    public void LogGemToResetGuildMark(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("RESET_GUILDMARK", "0", gem_value, sumlevel);
    }

    // 젬으로 길드이름 초기화
    public void LogGemToResetGuildName(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("RESET_GUILDNAME", "0", gem_value, sumlevel);
    }

    // 젬으로 상품 목록 초기화
    public void LogGemToResetSuggestShop(int gem_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("RESET_SUGGEST", "0", gem_value, sumlevel);
    }


    // 골드 소모
    // 골드로 아이템을 구매하였다.
    public void LogGoldToItem(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("ITEM", "1", gold_value, sumlevel);
    }

    // 골드로 룬스톤을 구매하였다.
    public void LogGoldToRune(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("RUNE", "1", gold_value, sumlevel);
    }

    // 골드로 아이템을 강화 하였다.
    public void LogGoldToItemUpgrade(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("ITEM_UP", "1", gold_value, sumlevel);
    }

    // 골드로 아이템을 합성 하였다.
    public void LogGoldToItemSynthesize(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("ITEM_SY", "1", gold_value, sumlevel);
    }

    // 골드로 아이템을 승급 하였다.
    public void LogGoldToItemPromotion(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("ITEM_PM", "1", gold_value, sumlevel);
    }

    public void LogGoldToItemOption(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("ITEM_OC", "1", gold_value, sumlevel);
    }

    public void LogGoldToBAG(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("BAG", "1", gold_value, sumlevel);
    }

    // 골드로 조력자를 구매하였다.
    public void LogGoldToHelper(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("HELPER", "1", gold_value, sumlevel);
    }

    // 골드로 조력자를 승급하였다.
    public void LogGoldToHelperUp(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("HELPER_UP", "1", gold_value, sumlevel);
    }

    // 골드로 아바타를 구매하였다.
    public void LogGoldToAvatar(int gold_value, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceMoneyConsumption("AVATAR", "1", gold_value, sumlevel);
    }

    // 게임내 머무는 화면
    // 화면이 변경되면 한번씩 호출해주도록 하자
    public void LogScreen(string screen_name, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GoogleAnalyticsV4.instance.LogScreen(screen_name);
        GameAnalytics.traceEvent("Screen", screen_name, "", "", 1.0f, sumlevel);
    }

    // 팝업을 띄웠을때 스크린이름과 팝업 이름 레벨 이름 호출
    public void LogPopup(string screen_name, string Popup_name, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GoogleAnalyticsV4.instance.LogScreen(Popup_name);
        GameAnalytics.traceEvent("Screen", screen_name, Popup_name, "", 1.0f, sumlevel);
    }

    // 리소스 로딩 종료
    // 게임 초기 리소스 로딩이 완료되면 호출
    public void LogResourceLoaded()
    {
        GameAnalytics.traceEvent("Performance", "Finish_Resource_Load", "", "", Time.realtimeSinceStartup, 0);
        GoogleAnalyticsV4.instance.LogEvent("Performance", "Finish_Resource_Load", "", (long)Time.realtimeSinceStartup);
    }

    // 리소스 다운 종료
    // 최초 설치시 리소스 다운로드를 해야할경우 사용하자
    public void LogResourceDownloaded()
    {
        GameAnalytics.traceEvent("Performance", "Finish_Resource_Down", "", "", Time.realtimeSinceStartup, 0);
        GoogleAnalyticsV4.instance.LogEvent("Performance", "Finish_Resource_Down", "", (long)Time.realtimeSinceStartup);
    }

    // 던전 클리어시 호출
    public void LogClearDungeon(string dungeonGroup, string dungeonNumber, float clearsecond, string job, int level, int guardianlevel, int power, int attack, int defense, int life)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceEvent("Balance", "Dungeon_Clear_Time", dungeonGroup + "_" + dungeonNumber, job, clearsecond, sumlevel);
        GoogleAnalyticsV4.instance.LogEvent("Dungeon_Clear_Time", dungeonGroup + "_" + dungeonNumber, job, (long)clearsecond);

        GameAnalytics.traceEvent("Balance", "Dungeon_Clear_Power", dungeonGroup + "_" + dungeonNumber, job, power, sumlevel);
        GoogleAnalyticsV4.instance.LogEvent("Dungeon_Clear_Power", dungeonGroup + "_" + dungeonNumber, job, (long)power);

        GameAnalytics.traceEvent("Balance", "Dungeon_Clear_Attack", dungeonGroup + "_" + dungeonNumber, job, attack, sumlevel);
        GoogleAnalyticsV4.instance.LogEvent("Dungeon_Clear_Attack", dungeonGroup + "_" + dungeonNumber, job, (long)attack);

        GameAnalytics.traceEvent("Balance", "Dungeon_Clear_Defense", dungeonGroup + "_" + dungeonNumber, job, defense, sumlevel);
        GoogleAnalyticsV4.instance.LogEvent("Dungeon_Clear_Defense", dungeonGroup + "_" + dungeonNumber, job, (long)defense);

        GameAnalytics.traceEvent("Balance", "Dungeon_Clear_Life", dungeonGroup + "_" + dungeonNumber, job, life, sumlevel);
        GoogleAnalyticsV4.instance.LogEvent("Dungeon_Clear_Life", dungeonGroup + "_" + dungeonNumber, job, (long)life);

        IgaworksUnityPluginAOS.Adbrix.firstTimeExperience("Dungeon_" + dungeonGroup + "_" + dungeonNumber);
        IgaworksUnityPluginAOS.Adbrix.retention("Dungeon_" + dungeonGroup + "_" + dungeonNumber);
    }

    // 던전 클리어 실패시 호출
    public void LogFailedDungeon(string dungeonGroup, string dungeonNumber, float failedtime, string job, int level, int guardianlevel, int power, int attack, int defense, int life)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceEvent("Balance", "Dungeon_Failed_Time", dungeonGroup + "_" + dungeonNumber, job, failedtime, sumlevel);
        GoogleAnalyticsV4.instance.LogEvent("Dungeon_Failed_Time", dungeonGroup + "_" + dungeonNumber, job, (long)failedtime);

        GameAnalytics.traceEvent("Balance", "Dungeon_Failed_Power", dungeonGroup + "_" + dungeonNumber, job, power, sumlevel);
        GoogleAnalyticsV4.instance.LogEvent("Dungeon_Failed_Power", dungeonGroup + "_" + dungeonNumber, job, (long)power);

        GameAnalytics.traceEvent("Balance", "Dungeon_Failed_Attack", dungeonGroup + "_" + dungeonNumber, job, attack, sumlevel);
        GoogleAnalyticsV4.instance.LogEvent("Dungeon_Failed_Attack", dungeonGroup + "_" + dungeonNumber, job, (long)attack);

        GameAnalytics.traceEvent("Balance", "Dungeon_Failed_Defense", dungeonGroup + "_" + dungeonNumber, job, defense, sumlevel);
        GoogleAnalyticsV4.instance.LogEvent("Dungeon_Failed_Defense", dungeonGroup + "_" + dungeonNumber, job, (long)defense);

        GameAnalytics.traceEvent("Balance", "Dungeon_Failed_Life", dungeonGroup + "_" + dungeonNumber, job, life, sumlevel);
        GoogleAnalyticsV4.instance.LogEvent("Dungeon_Failed_Life", dungeonGroup + "_" + dungeonNumber, job, (long)life);

        IgaworksUnityPluginAOS.Adbrix.retention("Dungeon_Failed_" + dungeonGroup + "_" + dungeonNumber);
        
    }

    // 레벨업
    // 인게임이나 퀘스트 완료로 인해서 레벨이 변동되면 사용하자
    public void LogLevel(string job, int level, int guardianlevel)
    {
        GoogleAnalyticsV4.instance.LogEvent("Level", job, level.ToString("000"), 1);
        GoogleAnalyticsV4.instance.LogEvent("Level", "Total", level.ToString("000"), 1);
        if(guardianlevel > 0)
        {
            GoogleAnalyticsV4.instance.LogEvent("GuardianLevel", job, guardianlevel.ToString("00000"), 1);
            GoogleAnalyticsV4.instance.LogEvent("GuardianLevel", "Total", guardianlevel.ToString("00000"), 1);
            IgaworksUnityPluginAOS.Adbrix.retention("GuardianLevel_" + guardianlevel.ToString("00000"));

        }
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceLevelUp(sumlevel);
        IgaworksUnityPluginAOS.Adbrix.retention("Level_" + sumlevel.ToString("00000"));
        IgaworksUnityPluginAOS.Adbrix.setCustomCohort(IgaworksUnityPluginAOS.CohortVariable.COHORT_1, "Level_"+ sumlevel);
    }

    // 스킬 사용
    // 던전에서 사용되는 스킬 분석
    public void LogUseSkillinDungeon(string skillname, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceEvent("Balance", "UseSkill_Dungeon", skillname, "", 1.0f, sumlevel);
        GoogleAnalyticsV4.instance.LogEvent("UseSkill_Dungeon", skillname, sumlevel.ToString("00000"), 1);
    }

    // 스킬 사용
    // PVP에서 사용되는 스킬 분석
    public void LogUseSkillinPVP(string skillname, int level, int guardianlevel)
    {
        int guardian = (guardianlevel / 100) * 100;
        int sumlevel = level + guardian;
        GameAnalytics.traceEvent("Balance", "UseSkill_PVP", skillname, "", 1.0f, sumlevel);
        GoogleAnalyticsV4.instance.LogEvent("UseSkill_PVP", skillname, level.ToString("00000"), 1);
    }

    // 신규 유저의 활동및 이탈구간 파악
    public void LogNewUserActivity(string code)
    {
        IgaworksUnityPluginAOS.Adbrix.firstTimeExperience(code);
    }

    public void ShowCouponDialog()
    {
        IgaworksUnityPluginAOS.Coupon.showCouponDialog(true);
    }

    public void InputCouponNumber(string value)
    {
        IgaworksUnityPluginAOS.Coupon.checkCoupon(value);
    }

    void OnSendCouponSucceed(string msg, int itemKey, string itemName, long quantity)
    {
        //msg : 쿠폰사용결과
        //itemKey : 사용된 쿠폰에서 지급할 가상화폐의 키, Deprecated							
        //itemName : 사용된 쿠폰에서 지급할 가상화폐
        //quantity : 사용된 쿠폰의 가치
    }

    void OnSendCouponFailed(string msg)
    {
        //msg : 쿠폰사용결과							
    }
}
